@@ -7,7 +7,6 @@
 
 #if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
 #include <KTerminalLauncherJob>
-#include <KWindowConfig>
 #endif
 
 #include <QGuiApplication>
@@ -19,8 +18,8 @@
 
 #include <QProcess>
 
-#include <MauiKit3/Core/fmh.h>
-#include <MauiKit3/FileBrowsing/fmstatic.h>
+#include <MauiKit4/Core/fmh.h>
+#include <MauiKit4/FileBrowsing/fmstatic.h>
 
 #if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
 #include "indexinterface.h"
@@ -115,7 +114,7 @@ bool IndexInstance::attachToExistingInstance(const QList<QUrl>& inputUrls, bool
         }
     }
 
-    for (const auto& interface: qAsConst(dolphinInterfaces))
+    for (const auto& interface: std::as_const(dolphinInterfaces))
     {
         auto reply = openFiles ? interface.first->openFiles(newUrls, splitView) : interface.first->openDirectories(newUrls, splitView);
         reply.waitForFinished();
@@ -166,12 +165,12 @@ Index::Index(QObject *parent)
 #endif
 }
 
-void Index::openDirectories(const QStringList &dirs, bool splitView)
+void Index::openDirectories(const QStringList &dirs, bool)
 {
     openPaths(dirs);
 }
 
-void Index::openFiles(const QStringList &files, bool splitView)
+void Index::openFiles(const QStringList &files, bool)
 {
     openPaths(files);
 }
@@ -206,12 +205,12 @@ void Index::pasteIntoFolder()
 
 }
 
-void Index::changeUrl(const QUrl &url)
+void Index::changeUrl(const QUrl &)
 {
 
 }
 
-void Index::slotTerminalDirectoryChanged(const QUrl &url)
+void Index::slotTerminalDirectoryChanged(const QUrl &)
 {
 
 }
@@ -221,12 +220,12 @@ void Index::quit()
     QCoreApplication::quit();
 }
 
-void Index::openNewTab(const QUrl &url)
+void Index::openNewTab(const QUrl &)
 {
 
 }
 
-void Index::openNewTabAndActivate(const QUrl &url)
+void Index::openNewTabAndActivate(const QUrl &)
 {
 
 }
